SystemOrganization addCategory: #'Graphics-External-Ffenestri'!

Object subclass: #HostWindowProxy
	instanceVariableNames: 'windowHandle sourceForm'
	classVariableNames: 'ActiveProxyClass Registry'
	poolDictionaries: ''
	category: 'Graphics-External-Ffenestri'!

!HostWindowProxy commentStamp: 'tpr 10/14/2004 16:00' prior: 0!
This is a proxy for a Host OS window and as such is considered a disposable item. When an image is restarted the client must recreate suitable instances from the information they hold. Platform specific subclasses are available to translate abstract requirements into possible platform concrete data.
There is a registry of instances so that when users let go they can be guaranteed to close down properly. Because the instances point to the source Form in use this can on occasion result in a cycle that defeats the Weak mechanism - hence the implementation of #executor & #asExecutor.
The only requirements placed on the sourceForm instvar are those of being like a DisplayScreen - can return a bits array, the width, depth etc AND able to respond to #resetProxy to remove and rebuild the window proxy!

!HostWindowProxy class methodsFor: 'system startup' stamp: 'tpr 10/14/2004 16:02'!
activeWindowProxyClass
	"Return the concrete HostWindowProxy subclass for the platform on which we are
currently running."

	HostWindowProxy allSubclasses do: [:class |
		class isActiveHostWindowProxyClass ifTrue: [^ class]].

	"no responding subclass; use HostWindowProxy"
	^ HostWindowProxy
! !

!HostWindowProxy class methodsFor: 'class initialization' stamp: 'PavelKrivanek 6/10/2011 17:00'!
initialize
"Add me to the system startup list and make sure to do a file-in init for first time loading"
"HostWindowProxy initialize"
	self startUp. "make sure we init on code load"
	Smalltalk addToStartUpList: self.! !

!HostWindowProxy class methodsFor: 'system startup' stamp: 'tpr 10/1/2004
16:07'!
isActiveHostWindowProxyClass
"subclasses must override this"
	self subclassResponsibility! !

!HostWindowProxy class methodsFor: 'initialize-release' stamp: 'tpr 10/1/2004
16:35'!
on: aSourceForm
"Build a new window proxy by finding the appropriate platform specific subclass
and setting it up for this Form-like argument"
	^ActiveProxyClass new on: aSourceForm! !

!HostWindowProxy class methodsFor: 'registry' stamp: 'HenrikSperreJohansen 5/20/2010 22:37'!
register: anObject
"boilerplate WeakRegistry usage"
	^self registry add: anObject! !

!HostWindowProxy class methodsFor: 'registry' stamp: 'HenrikSperreJohansen 5/20/2010 22:37'!
registry
"boilerplate WeakRegistry usage"
	^Registry ifNil: [Registry := WeakRegistry new]! !

!HostWindowProxy class methodsFor: 'system startup' stamp: 'lr 7/4/2009 10:42'!
setDefaultWindowProxyClass
	"connect to the proper platform subclass of proxy"
	ActiveProxyClass := self activeWindowProxyClass! !

!HostWindowProxy class methodsFor: 'system startup' stamp: 'tpr 10/12/2004 19:39'!
startUp
"system startup - find the appropriate proxy class for this platform"
	self setDefaultWindowProxyClass.
	"any currently extant instances must tell their sourceForm to resetProxy in order to kill potentially wrong-platform versions and reset to correct-platform"
	self registry do:[:i| i resetProxy]! !

!HostWindowProxy class methodsFor: 'registry' stamp: 'HenrikSperreJohansen 5/20/2010 22:38'!
unregister: anObject
"boilerplate WeakRegistry usage"
	^self registry remove: anObject ifAbsent:[]! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'lr 7/4/2009 10:42'!
asExecutor
	sourceForm := nil! !

!HostWindowProxy methodsFor: 'window decorations' stamp: 'tpr 9/28/2004 15:52'!
attributes
"return the ByteArray representing the desired window attributes. This is utterly platform dependent and my default is an empty ByteArray to signify a default window"
	^ByteArray new! !

!HostWindowProxy methodsFor: 'metrics' stamp: 'tpr 9/28/2004 15:47'!
bits
"return the bits - normally of the sourceForm"
	^sourceForm bits! !

!HostWindowProxy methodsFor: 'initialize-release' stamp: 'tpr 10/6/2004 21:20'!
close
	"close this window"
	windowHandle ifNil: [^self].
	self unregister.
	self primitiveWindowClose: windowHandle! !

!HostWindowProxy methodsFor: 'window decorations' stamp: 'tpr 10/7/2004 11:33'!
defaultWindowType
"set up my attributes to be a default window - a titlebar, usual decorations etc"
	^self subclassResponsibility! !

!HostWindowProxy methodsFor: 'metrics' stamp: 'tpr 9/28/2004 16:08'!
depth
"return the depth - normally of the sourceForm"
	^sourceForm depth! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'tpr 9/30/2004 13:10'!
executor
	^self shallowCopy asExecutor! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'tpr 10/6/2004 21:20'!
finalize
	"close this window"
	self close! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 9/28/2004 15:47'!
forceToScreen: damageRectangle 
	"update the area of the sourceForm defined by damageRectangle"
	self
		primitiveUpdateHostWindow: windowHandle
		bitmap: self bits
		width: self width
		height: self height
		depth: self depth
		left: damageRectangle left
		right: damageRectangle right
		top: damageRectangle top
		bottom: damageRectangle bottom! !

!HostWindowProxy methodsFor: 'metrics' stamp: 'tpr 9/28/2004 15:47'!
height
"return the height - normally of the sourceForm"
	^sourceForm height! !

!HostWindowProxy methodsFor: 'accessing' stamp: 'tpr 10/6/2004 14:29'!
isOpen
"am I already opened?"
	^windowHandle notNil! !

!HostWindowProxy methodsFor: 'metrics' stamp: 'tpr 9/28/2004 15:47'!
offset
"return the offset - normally of the sourceForm"
	^sourceForm offset! !

!HostWindowProxy methodsFor: 'initialize-release' stamp: 'lr 7/4/2009 10:42'!
on: aSourceForm 
	"set my sourceForm; usually an actual Form but so long as methods like bits, height etc work, it can be anything"
	sourceForm := aSourceForm! !

!HostWindowProxy methodsFor: 'initialize-release' stamp: 'tpr 10/7/2004 11:17'!
open
	"open a host window built around my position, size and bitmap"
	windowHandle
		ifNil: [sourceForm
				ifNotNil:[windowHandle := self
						primitiveCreateHostWindowWidth: self width
						height: self height
						originX: self offset x
						y: self offset y
						attributes: self attributes.
						windowHandle ifNotNil:[self register].
						^windowHandle]]! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 9/28/2004 13:22'!
primitiveCreateHostWindowWidth: w height: h originX: x y: y attributes: list
"create and open a host window. list is a ByteArray list of window attributes in some platform manner. See subclasses for information"
	<primitive: 'primitiveCreateHostWindow' module: 'HostWindowPlugin'>
	^self error: 'Unable to create Host Window'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:31'!
primitiveUpdateHostWindow: id bitmap: bitmap width: w height: h depth: d left: l
right: r top: t bottom: b 
	"Force the pixels to the screen. The bitmap details and affected area are given
explicitly to avoid dependence upon any object structure"
	<primitive: 'primitiveShowHostWindowRect' module:'HostWindowPlugin'>
	^self windowProxyError: 'update'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:31'!
primitiveWindowClose: id
"Close the window"
	<primitive: 'primitiveCloseHostWindow' module: 'HostWindowPlugin'>
	^self windowProxyError: 'close'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:32'!
primitiveWindowPosition: id
"Find the topleft corner of the window"
	<primitive: 'primitiveHostWindowPosition' module: 'HostWindowPlugin'>
	^self windowProxyError: 'get position'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:32'!
primitiveWindowPosition: id x: x y: y
"Set the topleft corner of the window - return what is actually set"
	<primitive: 'primitiveHostWindowPositionSet' module: 'HostWindowPlugin'>
	^self windowProxyError: 'set position'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:32'!
primitiveWindowSize: id
"Find the size of the window, just like primitiveScreenSize"
	<primitive: 'primitiveHostWindowSize' module: 'HostWindowPlugin'>
	^self windowProxyError: 'get size'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:33'!
primitiveWindowSize: id x: x y: y
"Set the size of the window, just like primitiveScreenSize. Return the actually
achieved size"
	<primitive: 'primitiveHostWindowSizeSet' module: 'HostWindowPlugin'>
	^self windowProxyError: 'set size'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 9/28/2004 13:26'!
primitiveWindowTitle: id string: titleString
"Set the label of the title bar of the window"
	<primitive: 'primitiveHostWindowTitle' module: 'HostWindowPlugin'>
	^self error: 'Unable to set title of Host Window'! !

!HostWindowProxy methodsFor: 'printing' stamp: 'tpr 9/29/2004 11:59'!
printOn: aStream
	super printOn:aStream.
	aStream nextPutAll: ' (windowIndex '.
	windowHandle printOn: aStream.
	aStream nextPut: $)! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 10/6/2004 14:31'!
recreate
"something has changed that require deleting the host window before opening it
with new attributes"
	self close; open! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'tpr 9/30/2004 12:56'!
register
	^self class register: self! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'tpr 10/12/2004 19:43'!
resetProxy
"tell my sourceForm to kill me (gulp) and resurrect me in the correct clothing"
	sourceForm ifNotNil:[ sourceForm resetProxy]! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'tpr 9/30/2004 12:56'!
unregister
	^self class unregister: self! !

!HostWindowProxy methodsFor: 'metrics' stamp: 'tpr 9/28/2004 15:47'!
width
"return the width - normally of the sourceForm"
	^sourceForm width! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 9/28/2004 13:34'!
windowPosition
	"return the current position of the window"
		^self primitiveWindowPosition: windowHandle! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 9/28/2004 13:34'!
windowPosition: aPoint
	"set the position of the window and then return the new position"
		^self primitiveWindowPosition: windowHandle x: aPoint x y: aPoint y! !

!HostWindowProxy methodsFor: 'accessing' stamp: 'tpr 10/7/2004 10:30'!
windowProxyError: problemString
	"Could be useful to raise an exception but not yet"! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 9/28/2004 13:35'!
windowSize
	"return the current size of the window "
		^self primitiveWindowSize: windowHandle! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 9/28/2004 13:35'!
windowSize: aPoint
	"Set the size of the window and then return the actually set size of the window - not neccessarily the same "
		^self primitiveWindowSize: windowHandle x: aPoint x y: aPoint y! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 9/28/2004 13:35'!
windowTitle: titleString
"set the label in the window titlebar to titleString"
	^self primitiveWindowTitle: windowHandle string: titleString! !

HostWindowProxy subclass: #MacOS9WindowProxy
	instanceVariableNames: 'windowClass windowAttributes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-External-Ffenestri'!

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
altDBoxProc
	^3
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:29'!
closeBoxAttribute
	^1! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
dBoxProc
	^1! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
documentProc
	^0! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:39'!
documentWindowClass
	^self zoomDocProc! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:41'!
floatGrowProc
	^1987
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:41'!
floatProc
	^1985
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:42'!
floatSideGrowProc
	^1995
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:42'!
floatSideProc
	^1993
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:42'!
floatSideZoomGrowProc
	^1999! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:42'!
floatSideZoomProc
	^1997! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:42'!
floatZoomGrowProc
	^1991
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:41'!
floatZoomProc
	^1989
! !

!MacOS9WindowProxy class methodsFor: 'system startup' stamp: 'StephaneDucasse 8/3/2010 22:43'!
isActiveHostWindowProxyClass
	"Am I active?"
	^OSPlatform isMacOS9! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
movableDBoxProc
	^5
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:10'!
noAttributes
	^0! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
noGrowDocProc
	^4
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
plainDBox
	^2! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:41'!
rDocProc
	^16
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:43'!
standardDocumentAttributes 
	^self closeBoxAttribute! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:39'!
zoomDocProc
	^8! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:41'!
zoomNoGrow
	^12
! !

!MacOS9WindowProxy methodsFor: 'accessing' stamp: 'StephaneDucasse 3/17/2010 21:30'!
attributes
	| val |
	val := ByteArray new: 8.
	val 
		unsignedLongAt: 1
		put: windowClass
		bigEndian: Smalltalk isBigEndian.
	val 
		unsignedLongAt: 5
		put: windowAttributes
		bigEndian: Smalltalk isBigEndian.
	^ val! !

!MacOS9WindowProxy methodsFor: 'metrics' stamp: 'JMM 10/7/2004 20:53'!
defaultWindowType
	self windowClass: self class documentWindowClass.
	self windowAttributes: self class standardDocumentAttributes.! !

!MacOS9WindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowAttributes
	^windowAttributes
! !

!MacOS9WindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowAttributes: aNumber
	windowAttributes := aNumber! !

!MacOS9WindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowClass
	^windowClass
! !

!MacOS9WindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowClass: aNumber
	windowClass := aNumber! !

HostWindowProxy subclass: #MacOSXWindowProxy
	instanceVariableNames: 'windowClass windowAttributes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-External-Ffenestri'!

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:19'!
activatesAttribute 
	^2 raisedTo: 17! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:25'!
alertWindowClass
	^1! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:28'!
altPlainWindowClass
	^16! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:20'!
asyncDragAttribute 
	^2 raisedTo: 23! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:16'!
closeBoxAttribute
	^2 raisedTo: 0! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:17'!
collapseBoxAttribute
	^2 raisedTo: 3! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:19'!
compositingAttribute 
	^2 raisedTo: 19! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:27'!
documentWindowClass
	^6! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:18'!
doesNotCycleAttribute
	^2 raisedTo: 15! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:29'!
drawerWindowClass
	^20! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:26'!
floatingWindowClass
	^5! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:13'!
fullZoomAttribute
	^self verticalZoomAttribute bitOr: self horizontalZoomAttribute! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:27'!
helpWindowClass
	^10! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:21'!
hideOnFullScreenAttribute 
	^2 raisedTo: 26! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:20'!
hideOnSuspendAttribute 
	^2 raisedTo: 24! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:16'!
horizontalZoomAttribute
	^2 raisedTo: 1! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:22'!
ignoreClicksAttribute 
	^2 raisedTo: 29! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:21'!
inWindowMenuAttribute 
	^2 raisedTo: 27! !

!MacOSXWindowProxy class methodsFor: 'system startup' stamp: 'StephaneDucasse 8/3/2010 22:43'!
isActiveHostWindowProxyClass
	"Am I active?"
	^OSPlatform isMacOSX! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:22'!
liveResizeAttribute 
	^2 raisedTo: 28! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:18'!
metalAttribute
	^2 raisedTo: 8! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:26'!
modalWindowClass
	^3! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:26'!
movableAlertWindowClass
	^2! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:26'!
movableModalWindowClass
	^4! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:10'!
noAttributes
	^0! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:22'!
noConstrainAttribute 
	^2 raisedTo: 31! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:20'!
noShadowAttribute 
	^2 raisedTo: 21! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:18'!
noUpdatesAttribute 
	^2 raisedTo: 16! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:19'!
opaqueForEventsAttribute 
	^2 raisedTo: 18! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:28'!
overlayWindowClass
	^14! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:28'!
plainWindowClass
	^13! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:17'!
resizableAttribute
	^2 raisedTo: 4! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:28'!
sheetAlertWindowClass
	^15! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:27'!
sheetWindowClass
	^11! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:17'!
sideTitlebarAttribute
	^2 raisedTo: 5! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:28'!
simpleWindowClass
	^18! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 20:40'!
standardDocumentAttributes 
	^self noConstrainAttribute + self standardHandlerAttribute + self closeBoxAttribute + self fullZoomAttribute + self collapseBoxAttribute + self resizableAttribute


"16r8200001E printStringBase: 2 '2r 10000010 00000000 00000000 00011110'"! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:25'!
standardFloatingAttributes
	^self closeBoxAttribute + self collapseBoxAttribute
! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:21'!
standardHandlerAttribute 
	^2 raisedTo: 25! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:18'!
toolbarButtonAttribute
	^2 raisedTo: 6! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:27'!
toolbarWindowClass
	^12! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:27'!
utilityWindowClass
	^8! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 20:31'!
verticalZoomAttribute
	^2 raisedTo: 2! !

!MacOSXWindowProxy methodsFor: 'accessing' stamp: 'StephaneDucasse 3/17/2010 21:12'!
attributes
	| val |
	val := ByteArray new: 8.
	val 
		unsignedLongAt: 1
		put: windowClass
		bigEndian: Smalltalk isBigEndian.
	val 
		unsignedLongAt: 5
		put: windowAttributes
		bigEndian: Smalltalk isBigEndian.
	^ val! !

!MacOSXWindowProxy methodsFor: 'metrics' stamp: 'JMM 10/7/2004 20:53'!
defaultWindowType
	self windowClass: self class documentWindowClass.
	self windowAttributes: self class standardDocumentAttributes.! !

!MacOSXWindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowAttributes
	^windowAttributes
! !

!MacOSXWindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowAttributes: aNumber
	windowAttributes := aNumber! !

!MacOSXWindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowClass
	^windowClass
! !

!MacOSXWindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowClass: aNumber
	windowClass := aNumber! !

DisplayScreen subclass: #DisplayHostWindow
	instanceVariableNames: 'windowProxy title windowType'
	classVariableNames: 'ActiveWindowIndex'
	poolDictionaries: ''
	category: 'Graphics-External-Ffenestri'!

!DisplayHostWindow commentStamp: '<historical>' prior: 0!
A subclass of DisplayScreen that uses a (platform appropriate) HostWindowProxy
to do its displaying in a separate host OS window. This is just one example of a
client for HostWindowProxy.
See #test #test2 and HostWindowTests for example usage.!

!DisplayHostWindow methodsFor: 'snapshots' stamp: 'tpr 10/14/2004 16:13'!
actualScreenSize
"return the host window size as if it were 'the' screen"
	^self windowSize! !

!DisplayHostWindow methodsFor: 'initialize-release' stamp: 'lr 7/4/2009 10:42'!
close
	"close this window"
	windowProxy ifNil: [ ^ self error: 'cannot close never opened window' ].
	"We don't use 'self windowProxy close' here because if we've never setup the window why do it now only to close it immediately?"
	windowProxy close.
	windowProxy := nil! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 9/21/2004 16:57'!
forceToScreen
	"update the area defined by my bounds"
	self forceToScreen: self boundingBox! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 10/7/2004 10:51'!
forceToScreen: damageRectangle 
	"update the area defined by damageRectangle"
	windowProxy ifNotNil:[ windowProxy forceToScreen: damageRectangle]! !

!DisplayHostWindow methodsFor: 'initialize-release' stamp: 'lr 7/4/2009 10:42'!
open
	"open the host window"
	windowProxy ifNil: [ windowProxy := HostWindowProxy on: self ].
	windowType ifNil: [ windowType := #defaultWindowType ].
	windowProxy perform: windowType.
	^ windowProxy open! !

!DisplayHostWindow methodsFor: 'snapshots' stamp: 'lr 7/4/2009 10:42'!
resetProxy
	"private - for use when resuming a snapshot file only. If the windowProxy had previously been created, nil it and reopen cleanly. IF you try to use this in a 'live' system it will NOT close the windows since startup conditions assume that proxies are invalid so we don't attempt to close them - since that could cause other problems"
	windowProxy ifNotNil: 
		[ windowProxy := nil.
		self open ]! !

!DisplayHostWindow methodsFor: 'private' stamp: 'tpr 10/14/2004 16:12'!
setExtent: extent depth: bitsPerPixel
"reset the host window size to suit the extent chosen"
	self windowSize: extent.
	^super setExtent: extent depth: bitsPerPixel
! !

!DisplayHostWindow methodsFor: 'testing' stamp: 'lr 7/4/2009 10:42'!
test
	"((DisplayHostWindow extent: 400@400 depth: 16 ) translateBy: 210@450) test"
	"Should
		a) open a window with the upper left portion of the current Display
		b) find the window size
		f) close the window"
	| size |
	self open.
	Display displayOn: self.
	self forceToScreen: self boundingBox.
	size := self windowSize.
	self close.
	^ size! !

!DisplayHostWindow methodsFor: 'testing' stamp: 'nice 3/5/2010 22:31'!
test2
	"((DisplayHostWindow extent: 400 @ 400 depth: 16 ) translateBy: 210 @ 450) test2"
	"Should
		a) open a window with the upper left portion of the current Display
		b) update the middle area with part of Display
		c) move the window from 210 @ 450 to 300 @ 300
		d) change the window title
		e) change the window size from 400 @ 400 to 600 @ 400
		f) wait 4 seconds so you can see the result
		g) close the window via the garbage collecttor finalizing it"
	self open.
	Display displayOn: self.
	self forceToScreen.
	Display displayOn: self at: -100 @ -200.
	self forceToScreen: (100 @ 100 extent: 200 @ 200).
	self windowPosition: 300 @ 300.
	self windowTitle: 'YooHoo!! New title'.
	self windowSize: 600 @ 400.
	(Delay forSeconds: 4) wait.! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 10/11/2004 16:56'!
windowPosition
	"return the current position of the window"
		
	^windowProxy ifNotNil:[ windowProxy windowPosition]! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 10/11/2004 16:56'!
windowPosition: aPoint
	"set the position of the window and then return the new position"
	^windowProxy ifNotNil:[ windowProxy windowPosition: aPoint]! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 10/11/2004 16:56'!
windowSize
	"return the current size of the window - not neccessarily the same as my bitmap"

	^windowProxy ifNotNil:[ windowProxy windowSize]! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 10/11/2004 16:56'!
windowSize: aPoint
	"Set the size of the window and then return the current size of the window -
not neccessarily the same "
		
	^windowProxy ifNotNil:[ windowProxy windowSize: aPoint]! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'lr 7/4/2009 10:42'!
windowTitle: titleString 
	"set the label in the window titlebar to titleString"
	title := titleString.
	windowProxy ifNotNil: [ windowProxy windowTitle: title ]! !
HostWindowProxy initialize!
